from dnsimple.service.accounts import Accounts
from dnsimple.service.certificates import Certificates
from dnsimple.service.contacts import Contacts
from dnsimple.service.domains import Domains
from dnsimple.service.identity import Identity
from dnsimple.service.oauth import Oauth
from dnsimple.service.registrar import Registrar
from dnsimple.service.services import Services
from dnsimple.service.templates import Templates
from dnsimple.service.tlds import Tlds
from dnsimple.service.vanity_name_servers import VanityNameServers
from dnsimple.service.webhooks import Webhooks
from dnsimple.service.zones import Zones



# -*- coding: utf-8 -*-
from setuptools import setup, find_packages

from dnsimple.version import version

with open("README.md", "r") as f:
    readme = f.read()

setup(
    name="dnsimple",
    version=version,
    description="DNSimple API service for python",
    long_description_content_type="text/markdown",
    long_description=readme,
    author="Enrique Comba Riepenhausen",
    author_email="enrique@ecomba.pro",
    url="https://github.com/dnsimple/dnsimple-python",
    license="MIT",
    packages=find_packages(exclude=["*.tests", "*.tests.*", "tests.*", "tests"]),
    classifiers=[
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Programming Language :: Python"
    ],
    install_requires=["requests", "omitempty"]
)
